@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2016-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,16 +22,28 @@
 
 KdeLoggingCategory::KdeLoggingCategory()
 {
-
 }
 
 bool KdeLoggingCategory::operator ==(const KdeLoggingCategory &other) const
 {
-    return (description == other.description) &&
-           (logName == other.logName);
+    return (description == other.description)
+           && (logName == other.logName) && (defaultCategory == other.defaultCategory);
+}
+
+bool KdeLoggingCategory::operator !=(const KdeLoggingCategory &other) const
+{
+    return !operator==(other);
 }
 
 bool KdeLoggingCategory::isValid() const
 {
     return !logName.isEmpty();
 }
+
+QDebug operator<<(QDebug d, const KdeLoggingCategory &cat)
+{
+    d << "description: " << cat.description;
+    d << "logname: " << cat.logName;
+    d << "default category: " << cat.defaultCategory;
+    return d;
+}
